"""Estimate overdispersion parameters

Functions
---------
estimate_lsse_parameters
    Estimate LSSE parameters
estimate_null_parameters
    Estimate NPBin parameters
"""

from overdisp.overdisp import estimate_lsse_parameters, estimate_null_parameters